import 'package:test/test.dart';

import 'package:chance/chance.dart';

void main() {
  final chance = new Chance();

  test('reaches min', () {
    var reachedMin = false;

    for (var i = 0; i < 5000000; ++i)
      if (chance.floating(min: -10.0, max: 10.0) <= -9.999) {
        reachedMin = true;
        break;
      }

    expect(reachedMin, isTrue);
  });

  test('reaches max', () {
    var reachedMax = false;

    for (var i = 0; i < 5000000; ++i)
      if (chance.floating(min: -10.0, max: 10.0) >= 9.999) {
        reachedMax = true;
        break;
      }

    expect(reachedMax, isTrue);
  });

  test('respects limits', () {
    for (var i = 0; i < 100000; ++i)
      expect(chance.floating(min: 0.0, max: 20.5), allOf(lessThan(20.5000001), greaterThan(-.0000001)));
  });

  test('works without min', () {
    var reachedMax = false;

    for (var i = 0; i < 100000; ++i) {
      final number = chance.integer(max: 10);
      if (number >= 9.99)
        reachedMax = true;
      expect(number, greaterThanOrEqualTo(0.0));
    }

    expect(reachedMax, isTrue);
  });

  test('works without arguments', () {
    for (var i = 0; i < 100000; ++i)
      expect(chance.floating(), allOf(greaterThanOrEqualTo(0.0), lessThanOrEqualTo(1.0)));
  });

  test('throws error on min > max', () {
    expect(() {chance.floating(min: 10.0, max: 5.0);}, throwsRangeError);
  });

  test('throws error if only min was provided', () {
    expect(() {chance.floating(min: 10.0);}, throwsStateError);
  });

  // TODO: Add test that proves an even distribution.
}
